"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.translatedCollectionResolvers = void 0;
var _handlerGraphql = require("@webiny/handler-graphql");
var _GqlTranslatedCollectionMapper = require("./mappers/GqlTranslatedCollectionMapper");
var _SaveTranslatedCollectionUseCase = require("../useCases/SaveTranslatedCollectionUseCase");
var _GetOrCreateTranslatedCollectionUseCase = require("../useCases/GetOrCreateTranslatedCollectionUseCase");
var _2 = require("../..");
const translatedCollectionResolvers = exports.translatedCollectionResolvers = {
  TranslationsQuery: {
    getTranslatedCollection: async (_, args, context) => {
      try {
        const {
          collectionId,
          languageCode
        } = args;
        const getBaseCollection = new _2.GetTranslatableCollectionUseCase(context);
        const baseCollection = await getBaseCollection.execute(collectionId);
        if (!baseCollection) {
          return new _handlerGraphql.NotFoundResponse(`TranslatableCollection ${collectionId} was not found!`);
        }
        const getTranslatedCollection = new _GetOrCreateTranslatedCollectionUseCase.GetOrCreateTranslatedCollectionUseCase(context);
        const translatedCollection = await getTranslatedCollection.execute({
          collectionId,
          languageCode
        });
        const translatedCollectionDto = _GqlTranslatedCollectionMapper.GqlTranslatedCollectionMapper.toDTO(baseCollection, translatedCollection);
        return new _handlerGraphql.Response(translatedCollectionDto);
      } catch (err) {
        return new _handlerGraphql.ErrorResponse(err);
      }
    }
  },
  TranslationsMutation: {
    saveTranslatedCollection: async (_, args, context) => {
      const {
        collectionId,
        languageCode,
        items
      } = args;
      try {
        const useCase = new _SaveTranslatedCollectionUseCase.SaveTranslatedCollectionUseCase(context);
        const collection = await useCase.execute({
          collectionId,
          languageCode,
          items
        });
        const getBaseCollection = new _2.GetTranslatableCollectionUseCase(context);
        const baseCollection = await getBaseCollection.execute(collectionId);
        if (!baseCollection) {
          return new _handlerGraphql.NotFoundResponse(`TranslatableCollection ${collectionId} was not found!`);
        }
        return new _handlerGraphql.Response(_GqlTranslatedCollectionMapper.GqlTranslatedCollectionMapper.toDTO(baseCollection, collection));
      } catch (err) {
        return new _handlerGraphql.ErrorResponse(err);
      }
    }
  }
};

//# sourceMappingURL=resolvers.js.map